/** 
    Copyright 2002 Cyril Picard

    This file is part of the GEDCOMViewer tool 
    (developed within the Genealogy Free Software Tools project).

    The GEDCOMViewer tool is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    The GEDCOMViewer tool is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with the GEDCOMViewer tool ; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

**/

#include "UnlinkMenuItemsFactory.hh"

#include "config.h"
#include <libgnome/libgnome.h>

MenuItems_t * UnlinkMenuItemsFactory::getMenuItems(void) const
{
  MenuItems_t * res = new MenuItems_t;
  OneMenuItems_t * tmp = new OneMenuItems_t;
  tmp->push_back(new MenuItem(_("Remove link"),"","",MenuItem::e_Unlink));
  res->push_back(*tmp);
  delete tmp; tmp = 0;
  return res;
}
